@@ -2,7 +2,7 @@ from django.contrib import sitemaps
 from django.urls import reverse
 from django.contrib.sites.models import Site
 
-from snowebsvg.models import Collection, Svg
+from snowebsvg.models import Collection, GroupSvg, Svg
 
 
 class BaseSitemap(sitemaps.Sitemap):
@@ -15,22 +15,22 @@ class BaseSitemap(sitemaps.Sitemap):
         return super(BaseSitemap, self).get_urls(site=site, **kwargs)
 
 
-class StaticSitemap(BaseSitemap):
-
-    def items(self):
-        return ['app:collection']
-
-    def location(self, item):
-        return reverse(item)
-
-
 class CollectionSitemap(BaseSitemap):
 
     def items(self):
         return Collection.objects.all()
 
     def location(self, item):
-        return reverse('app:group', kwargs={'collection_key': item.key})
+        return reverse('app:svg_search', kwargs={'key': item.key})
+
+
+class GroupSvgSitemap(BaseSitemap):
+
+    def items(self):
+        return GroupSvg.objects.all()
+
+    def location(self, item):
+        return reverse('app:svg_search', kwargs={'key': item.key})
 
 
 class SvgSitemap(BaseSitemap):
@@ -44,3 +44,12 @@ class SvgSitemap(BaseSitemap):
             'group_key': item.group.key,
             'svg_key': item.key
         })
+
+
+class StaticSitemap(BaseSitemap):
+
+    def items(self):
+        return ['app:svg_settings']
+
+    def location(self, item):
+        return reverse(item)
